==> fengoffice_1.7.5.zip: fengoffice/language/es_la/help.php <==
<?php return array(
	'chelp pending tasks widget' => 'Este widget muestra sus tareas incompletas. Solo puedes ver las tareas incompletas que tienes asignadas, o puedes modificar la configuración en las opciones del panel principal.',
	'chelp documents widget' => 'Este widget muestra los documentos más recientes en el área de trabajo seleccionada.',
	'chelp active tasks widget' => 'Este widget muestra sus tareas activas y en pausa.',
	'chelp late tasks widget' => 'Este widget muestra sus tareas e hitos atrasados, así como los que finalizan hoy, ordenados por fecha de finalización.',
	'chelp calendar widget' => 'Este widget muestra los eventos de la semana corriente, tareas vencidas e hitos. Puedes crear un nuevo evento haciendo clic en un día.',
	'chelp comments widget' => 'Este widget muestra los últimos comentarios para objetos del área de trabajo actual ',
	'chelp dashboard info widget' => 'Este widget muestra información para el área de trabajo actual, incluyendo usuarios con accesos, contactos asignados, etc...',
	'chelp emails widget' => 'Este widget muestra los correos clasificados en el área de trabajo actual.',
	'chelp messages widget' => 'Este widget muestra las últimas notas para el área de trabajo seleccionada.',
	'chelp active tasks panel' => 'Este panel muestra sus tareas activas sin importar el área de trabajo actual. El sistema le permite pausar, continuar, detenerlas o marcarlas como completadas.',
	'chelp general timeslots panel' => 'Este panel muestra los tiempos de trabajo realizados dentro del área de trabajo seleccionada.',
	'chelp personal account' => 'Esta es su cuenta personal.<br/>En esta vista puedes actualizar tu perfil e imagen ,cambiar tu contraseña y editar tus preferencias personales.',
	'chelp user account' => 'Esta es una cuenta de usuario.',
	'chelp user account admin' => 'Siendo administrador, puedes actualizar el perfil e imagen del usuario, cambiar su contraseña y editar sus preferencias a través de esta vista.',
	'chelp addfile' => 'Usted tiene la opción de cargar un archivo o un enlace web.<br/>
						<b> Cargar archivo:</b> Le permite subir cualquier tipo de archivo de su disco local.<br/>
						<b> Cargar enlace web:</b> Le permite introducir una dirección web.<br/>',
	'remove context help' => 'Quitar este mensaje de ayuda',
	'chelp reporting panel' => 'Este es el panel de reportes. Aquí puede ejecutar reportes que involucren a cualquiera de los objetos que se listan a la izquierda.',
	'chelp reporting panel manage' => 'Este es el panel de reportes. Aquí puede ejecutar reportes que involucren a cualquiera de los objetos que se listan a la izquierda.<br/>Como tiene permisos de administrar reportes puede crear y administrar reportes personalizados para cada tipo de objeto.',
	'chelp reporting panel manage admin' => 'Este es el panel de reportes. Aquí puede ejecutar reportes que involucren a cualquiera de los objetos que se listan a la izquierda.<br/>Como tiene permisos de administrar reportes puede crear y administrar reportes personalizados para cada tipo de objeto. Estos permisos se establecen para cada usuario en la sección de permisos de usuario.',
	'chelp tasks list welcome' => 'Bienvenido al panel de tareas',
	'chelp tasks list' => '<br/>Puede aplicar uno de los siguientes filtros:<br/>							<b>Creado por</b>: sólo desplegar tareas creadas por un usuario o grupo específico <br/>							<b>Completado por</b>: sólo desplegar tareas completadas por un usuario o grupo específico <br/>							<b>Asignado a</b>: sólo desplegar tareas asignadas a un usuario o grupo específico <br/>							<b>Asignado por</b>: sólo desplegar tareas asignadas por un usuario o grupo específico <br/>							<b>Hito</b>: sólo desplegar tareas pertenecientes a un hito específico<br/>							<b>Prioridad</b>: sólo desplegar tareas con una prioridad específica (baja, normal, alta) <br/>							</td>							<td>							<br/>Puede agrupar tareas por los siguientes criterios (entre otros):<br/>							<b>Hito</b>: agrupar tareas por un hito específico <br/>							<b>Prioridad</b>: agrupar tareas por una prioridad específica (baja, normal, alta) <br/>							<b>Área de trabajo</b>: agrupar tareas por un área de trabajo específica <br/>',
	'help opt show' => 'Mostrar',
	'help opt hide' => 'Ocultar',
	'context help messages' => 'Ayuda contextual',
	'enable all chelp messages' => 'Para habilitar toda la ayuda contextual cerrada manualmente',
	'enable all chelp messages click' => 'Haga clic aquí',
	'help manual' => 'Manual de ayuda',
	'about us' => 'Acerca de nosotros',
	'success enable all context help' => 'Ayuda contextual reabierta exitosamente.',
	'success enable context help' => 'Ayuda contextual habilitada exitosamente.',
	'success disable context help' => 'Ayuda contextual deshabilitada exitosamente.',
	'how to purchase' => 'Como adquirir',
	'how to purchase desc' => 'Información acerca de nuestros diferentes planes y beneficios', 
	'add ticket' => 'Agregar un nuevo ticket de soporte',
	'add ticket desc' => "Para obtener ayuda personalizada acerca de Feng Office",
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_la/help.php <==
<?php return array(
	'chelp pending tasks widget' => 'Este widget muestra sus tareas incompletas. Solo puedes ver las tareas incompletas que tienes asignadas, o puedes modificar la configuración en las opciones del panel principal.',
	'chelp documents widget' => 'Este widget muestra los documentos más recientes en el área de trabajo seleccionada.',
	'chelp active tasks widget' => 'Este widget muestra sus tareas activas y en pausa.',
	'chelp late tasks widget' => 'Este widget muestra sus tareas e hitos atrasados, así como los que finalizan hoy, ordenados por fecha de finalización.',
	'chelp calendar widget' => 'Este widget muestra los eventos de la semana corriente, tareas vencidas e hitos. Puedes crear un nuevo evento haciendo clic en un día.',
	'chelp comments widget' => 'Este widget muestra los últimos comentarios para objetos del área de trabajo actual ',
	'chelp dashboard info widget' => 'Este widget muestra información para el área de trabajo actual, incluyendo usuarios con accesos, contactos asignados, etc...',
	'chelp emails widget' => 'Este widget muestra los correos clasificados en el área de trabajo actual.',
	'chelp messages widget' => 'Este widget muestra las últimas notas para el área de trabajo seleccionada.',
	'chelp active tasks panel' => 'Este panel muestra sus tareas activas sin importar el área de trabajo actual. El sistema le permite pausar, continuar, detenerlas o marcarlas como completadas.',
	'chelp general timeslots panel' => 'Este panel muestra los tiempos de trabajo realizados dentro del área de trabajo seleccionada.',
	'chelp personal account' => 'Esta es su cuenta personal.<br/>En esta vista puedes actualizar tu perfil e imagen ,cambiar tu contraseña y editar tus preferencias personales.',
	'chelp user account' => 'Esta es una cuenta de usuario.',
	'chelp user account admin' => 'Siendo administrador, puedes actualizar el perfil e imagen del usuario, cambiar su contraseña y editar sus preferencias a través de esta vista.',
	'chelp addfile' => 'Usted tiene la opción de cargar un documento o un enlace web.<br/>
						<b> Cargar documento:</b> Le permite subir cualquier tipo de documento de su disco local.<br/>
						<b> Cargar enlace web:</b> Le permite introducir una dirección web.<br/>',
	'remove context help' => 'Quitar este mensaje de ayuda',
	'chelp reporting panel' => 'Este es el panel de reportes. Aquí puede ejecutar reportes que involucren a cualquiera de los objetos que se listan a la izquierda.',
	'chelp reporting panel manage' => 'Este es el panel de reportes. Aquí puede ejecutar reportes que involucren a cualquiera de los objetos que se listan a la izquierda.<br/>Como tiene permisos de administrar reportes puede crear y administrar reportes personalizados para cada tipo de objeto.',
	'chelp reporting panel manage admin' => 'Este es el panel de reportes. Aquí puede ejecutar reportes que involucren a cualquiera de los objetos que se listan a la izquierda.<br/>Como tiene permisos de administrar reportes puede crear y administrar reportes personalizados para cada tipo de objeto. Estos permisos se establecen para cada usuario en la sección de permisos de usuario.',
	'chelp tasks list welcome' => 'Bienvenido al panel de tareas',
	'chelp tasks list' => '<br/>Puede aplicar uno de los siguientes filtros:<br/>							<b>Creado por</b>: sólo deplegar tareas creadas por un usuario o grupo específico <br/>							<b>Completado por</b>: sólo deplegar tareas completadas por un usuario o grupo específico <br/>							<b>Asignado a</b>: sólo deplegar tareas asignadas a un usuario o grupo específico <br/>							<b>Asignado por</b>: sólo deplegar tareas asignadas por un usuario o grupo específico <br/>							<b>Hito</b>: sólo deplegar tareas pertenecientes a un hito específico<br/>							<b>Prioridad</b>: sólo deplegar tareas con una prioridad específica (baja, normal, alta) <br/>							</td>							<td>							<br/>Puede agrupar tareas por los siguientes criterios (entre otros):<br/>							<b>Hito</b>: agrupar tareas por un hito específico <br/>							<b>Prioridad</b>: agrupar tareas por una prioridad específica (baja, normal, alta) <br/>							<b>Área de trabajo</b>: agrupar tareas por un área de trabajo específica <br/>',
	'help opt show' => 'Mostrar',
	'help opt hide' => 'Ocultar',
	'context help messages' => 'Ayuda contextual',
	'enable all chelp messages' => 'Para habilitar toda la ayuda contextual cerrada manualmente',
	'enable all chelp messages click' => 'Haga clic aquí',
	'help manual' => 'Manual de ayuda',
	'about us' => 'Acerca de nosotros',
	'success enable all context help' => 'Ayuda contextual reabierta exitosamente.',
	'success enable context help' => 'Ayuda contextual habilitada exitosamente.',
	'success disable context help' => 'Ayuda contextual deshabilitada exitosamente.',
	'how to purchase' => 'Como adquirir',
	'how to purchase desc' => 'Información acerca de nuestros diferentes planes y beneficios', 
	'add ticket' => 'Agregar un nuevo ticket de soporte',
	'add ticket desc' => "Para obtener ayuda personalizada acerca de Feng Office",
); ?>
